import queue
if False:
    from typing import Any, Optional, queue


def listen_default(sub,  # type: queue
                   block=True,  # type: bool
                   timeout=None,  # type: Optional[float]
                   empty=None  # type: Any
                   ):  # type: (...)->Any
    try:
        msg = (sub.listen(block=block, timeout=timeout))
        try:
            msg = next(msg)['data']
        except StopIteration:
            msg = empty
    except queue.Empty:
        msg = empty
    return msg



import pubsub


class WinCtrl:

    @staticmethod
    def key_stroke(key_entered):
        pubsub.publish("CVKeyStroke", key_entered)

    @staticmethod
    def quit():
        pubsub.publish("CVWinCmd", "quit")



import pubsub

if False:
    from typing import Union


class CamCtrl:

    @staticmethod
    def stop_cam(cam_id  # type: Union[int, str]
                 ):
        pubsub.publish("CVCamHandlers." + str(cam_id) + ".Cmd", 'quit')
        pubsub.publish("CVCams." + str(cam_id) + ".Cmd", 'quit')
